@@ -31,6 +31,9 @@ class Coordinate:
     def reverse(self):
         return Coordinate(-self._x, -self._y, -self._z)
 
+    def is_zero(self):
+        return abs(self.x - 0.0) < 1e-3 and abs(self.y - 0.0) < 1e-3 and abs(self.z - 0.0) < 1e-3
+
     def __repr__(self):
         return f"Coord - ({self._x}, {self._y}, {self._z})"
 
